Module options

Module options 

Structs

Options
Options that control the overall behaviour of a database.
ReadOptions
Options that control read operations.
Snapshot
An immutable snapshot of the database state at a particular sequence number.
WriteOptions
Options that control write operations.

Enums

CompressionType
Compression algorithm applied to SSTable data blocks.