ReadOptions

Struct ReadOptions 

pub struct ReadOptions<'snap> {
    pub verify_checksums: bool,
    pub fill_cache: bool,
    pub snapshot: Option<&'snap Snapshot<'snap>>,
}
Options that control read operations.

See include/leveldb/options.h.

Fields

verify_checksums: bool

Verify block checksums on every read in this operation.

When set, every SSTable data block read for this get or iterator call has its CRC32c checksum verified. Any mismatch returns Error::Corruption.

For database-wide verification without setting this on every ReadOptions, use Options::paranoid_checks instead.

Default: false.

fill_cache: bool

Cache blocks read during this operation in the block cache.

Set to false for bulk scans to avoid polluting the cache with data that is unlikely to be re-read soon (e.g. DbIter full-table scans).

Default: true.

snapshot: Option<&'snap Snapshot<'snap>>

Read as of this snapshot’s sequence number. None means “use an implicit snapshot of the current state”.