Structs
- Options
- Options that control the overall behaviour of a database.
- Read
Options - Options that control read operations.
- Snapshot
- An immutable snapshot of the database state at a particular sequence number.
- Write
Options - Options that control write operations.
Enums
- Compression
Type - Compression algorithm applied to SSTable data blocks.